@@ -54,7 +54,8 @@ assign("LOG_FILE_NAME", NULL,  .pkg.env)
                    data.frame(type = "character", scalar = FALSE,  row.names = "VecSpecifier[]", stringsAsFactors = FALSE),
                    data.frame(type = "list",      scalar = FALSE, row.names = "KeyValue[]",   stringsAsFactors = FALSE),
                    data.frame(type = "list",      scalar = FALSE, row.names = "StringPair[]", stringsAsFactors = FALSE),
-                   data.frame(type = "list",        scalar = FALSE, row.names = "Key<Keyed>[]", stringsAsFactors = FALSE))
+                   data.frame(type = "list",      scalar = FALSE, row.names = "Key<Keyed>[]", stringsAsFactors = FALSE),
+                   data.frame(type = "list",      scalar = FALSE, row.names = "string[][]",   stringsAsFactors = FALSE))
 
 #' Capabilities endpoints
 .h2o.__ALL_CAPABILITIES  <- "Capabilities"
@@ -66,6 +67,7 @@ assign("LOG_FILE_NAME", NULL,  .pkg.env)
 .h2o.__CLOUD          <- "Cloud?skip_ticks=true"
 .h2o.__SHUTDOWN       <- "Shutdown"
 .h2o.__DOWNLOAD_LOGS  <- "3/Logs/download"
+.h2o.__RESUME         <- "3/Recovery/resume"
 
 #' Removal Endpoints
 .h2o.__DKV            <- "DKV"
@@ -139,8 +141,14 @@ assign("LOG_FILE_NAME", NULL,  .pkg.env)
 .h2o.__LOAD_MODEL <- "Models.bin/"
 .h2o.__UPLOAD_MODEL <- "Models.upload.bin/"
 
+# Export/Import Frame Endpoints
+.h2o.__SAVE_FRAME <- function(frame_id) paste0("Frames/", frame_id, "/save")
+.h2o.__LOAD_FRAME <- "Frames/load"
+
+
 # Grid search 
 .h2o.__GRID <- function(algo) paste0("Grid/", algo)
+.h2o.__GRID_RESUME <- function(algo) paste0("Grid/", algo, "/resume")
 .h2o.__GRIDS <- function(grid_id, sort_by, decreasing) {
     if (missing(grid_id)) {
         "/Grids"
@@ -155,3 +163,9 @@ assign("LOG_FILE_NAME", NULL,  .pkg.env)
          url
     }
 }
+
+# Client version of R package
+.h2o.__CLIENT_VERSION_FILENAME <- "client_info.txt"
+
+# Return True if installed h2o package location contain .h2o.__CLIENT_VERSION_FILENAME file
+.h2o.__CLIENT_VERSION <- system.file(.h2o.__CLIENT_VERSION_FILENAME, package = "h2o") != ""
