@@ -255,13 +255,21 @@ h2o.getModel <- function(model_id) {
       type    <- mapping$type
       scalar  <- mapping$scalar
 
-      if(type == "numeric" && class(value) == "list" && length(value) == 0) #Special case when using deep learning with 0 hidden units
+      if (type == "numeric" && inherits(value, "list") && length(value) == 0) #Special case when using deep learning with 0 hidden units
         value <- 0
-      else if (type == "numeric" && value == "Infinity")
-        value <- Inf
-      else if (type == "numeric" && value == "-Infinity")
-        value <- -Inf
+      else if (type == "numeric") {
+        value[value == "Infinity"] <- Inf
+        value[value == "-Infinity"] <- -Inf
 
+        # if there is no loss of information for integers, convert to numeric
+        num_value <- as.numeric(value)
+        if (is.character(value) && all(
+          grepl(".", value, fixed = TRUE) | # Not an integer
+          !is.finite(num_value) | # Or not a finite number (NaN/Inf)
+          (-2^.Machine$double.digits <= num_value & # Or lies between the min and max fully representable number
+            num_value <= 2^.Machine$double.digits)))
+          value <- num_value
+      }
       # Parse frame information to a key
       if (type == "H2OFrame")
         value <- value$name
@@ -419,7 +427,7 @@ as.data.frame.H2OSegmentModels <- function(x, ...) {
 #' @export
 h2o.download_pojo <- function(model, path=NULL, getjar=NULL, get_jar=TRUE, jar_name="") {
   
-  if (class(model) == "H2OAutoML") {
+  if (inherits(model, "H2OAutoML")) {
     model <- model@leader
   }
   
@@ -499,7 +507,7 @@ h2o.download_pojo <- function(model, path=NULL, getjar=NULL, get_jar=TRUE, jar_n
 #' @export
 h2o.download_mojo <- function(model, path=getwd(), get_genmodel_jar=FALSE, genmodel_name="", genmodel_path="", filename="") {
   
-  if (class(model) == "H2OAutoML") {
+  if (inherits(model, "H2OAutoML")) {
     model <- model@leader
   }
 
